@@ -152,7 +152,7 @@ def evaluate_report(report, question=None, qitem=None, passall=False, verbose=Fa
         res = UTextTestRunner(verbosity=2, resultclass=UTextResult).run(suite)
         details = {}
         for s, msg in res.successes + res.failures + res.errors:
-            key = s.cache_id()
+            key = (q.__name__, s._testMethodName) # cannot use the cache_id method bc. it is not compatible with plain unittest.
             detail = {}
             if (s,msg) in res.successes:
                 detail['status'] = "pass"
